/*
 * Copyright (c) 2019 Meltytech, LLC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

//import QtQuick 2.1
//import QtQuick.Controls 1.0
//import QtQuick.Layouts 1.0

import QtQuick 2.0
import QtQuick.Controls 1.1
import QtQuick.Layouts 1.1
import Shotcut.Controls 1.0
import QtQuick.Dialogs 1.1


Item {
	width: 300
    height: 300
    Component.onCompleted: {
        if (filter.isNew) {
            // Set default parameter values
            filter.set('animation', 1)
            textArea.text = 'Type any text of\nyour choice here !'
            filter.set('family', 'arial')
            filter.set('size', 72)
            filter.set('weight', 500)
            filter.set('colorfont', '#ffffff')
            filter.set('border', 0)
            filter.set('colorborder', '#000000')
            filter.set('shadow', 0)
            filter.set('colorshadow', '#000000')
            filter.set('colorbackground', 'purple')
            filter.set('lineheight', 100)
            filter.set('letterspacing', 0)
            filter.set('textalign', 'center')
        } else {
            // Initialize parameter values
            textArea.text = filter.get('argument')
        }
        animationCombo.currentIndex = filter.getDouble('animation') - 1
        refreshFontButton()
        taille.text = filter.getDouble('size')
        colorFont.value = filter.get('colorfont')
        contour.value = filter.get('border')
        colorBorder.value = filter.get('colorborder')
        shadow.value = filter.get('shadow')
        colorShadow.value = filter.get('colorshadow')
        bgcolor.value = filter.get('colorbackground')
        lineHeight.value = filter.get('lineheight')
        letterspacing.value = filter.get('letterspacing')
        setRadioButton()
        
    }
    

    function refreshFontButton() {
        var s = filter.get('family')
        if (filter.getDouble('weight') > 10 * Font.Medium)
            s += ' ' + qsTr('Bold')
        if (filter.get('style') === 'italic')
            s += ' ' + qsTr('Italic')
        fontButton.text = s
    }
    
    function setRadioButton() {
    	var a = filter.get('textalign')
    	if (a == 'left') leftRadioButton.checked = true
    	else if (a == 'right') rightRadioButton.checked = true
    	else centerRadioButton.checked = true
    }
    
    ExclusiveGroup { id: halignGroup }

    GridLayout {
        columns: 3
        anchors.fill: parent
        anchors.margins: 8
        
        Label { 
        	Layout.alignment: Qt.AlignRight
        	text: qsTr('Animation') 
        }

        RowLayout {
            Layout.columnSpan: 2
            
            ComboBox {
                id: animationCombo
                model: [qsTr('Animation 1'), qsTr('Animation 2'), qsTr('Animation 3'), qsTr('Animation 4'),
                qsTr('Animation 5'), qsTr('Animation 6'), qsTr('Animation 7'), qsTr('Animation 8'),
                qsTr('Animation 9'), qsTr('Animation 10'), qsTr('Animation 11'), qsTr('Animation 12'),
                qsTr('Animation 13'), qsTr('Animation 14'), qsTr('Animation 15'), qsTr('Animation 16'),
                qsTr('Animation 17'), qsTr('Animation 18'), qsTr('Animation 19'), qsTr('Animation 20'),
                qsTr('Animation 21'), qsTr('Animation 22'), qsTr('Animation 23'), qsTr('Animation 24'), qsTr('Without animation')]
                onCurrentIndexChanged: {
					filter.set('animation', currentIndex + 1)
					filter.set('_reload', 1)
				}
            }
            Item { width: 15 }
            TextArea {
            	id: textArea
            	Layout.columnSpan: 5
            	textFormat: TextEdit.PlainText
            	wrapMode: TextEdit.NoWrap
            	Layout.minimumHeight: 40
            	Layout.maximumHeight: 60
            	Layout.minimumWidth: 250
            	Layout.maximumWidth: 300
            	text: '__empty__' // workaround initialization problem
            	property int maxLength: 120
            	onTextChanged: {
                	if (text === '__empty__') return
                	if (length > maxLength) {
                    	text = text.substring(0, maxLength)
                    	cursorPosition = maxLength
                	}
                	//if (!parseInt(filter.get(useFontSizeProperty)))
                    //	filter.set('size', profile.height / text.split('\n').length)
                	filter.set('argument', text)
            	}
        	}
        }
        Label { 
        	Layout.alignment: Qt.AlignRight
        	text: qsTr('Font') 
        }
        RowLayout {
            Layout.columnSpan: 2
            Button {
                id: fontButton
                Layout.preferredWidth: 200
            	onClicked: {
                    fontDialog.open()
                }
                FontDialog {
                    id: fontDialog
                    title: "Choose a font"
                    modality: Qt.ApplicationModal
                    onFontChanged: {
                        filter.set('family', font.family)
                        filter.set('weight', 10 * font.weight )
                        filter.set('style', font.italic? 'italic' : 'normal' )
                        filter.set('size', font.pixelSize)
                    }
                    onAccepted: {
                    	taille.text = font.pixelSize
                        refreshFontButton()
                        filter.set('_reload', 1)
                    }
                    onRejected: {
                        return
                    }
                }
            }
            Item { width: 15 }
            Label { 
        		Layout.alignment: Qt.AlignRight
        		text: qsTr('Size ') 
        	}
        	TextField {
        		id: taille
        		Layout.preferredWidth : 40
        		horizontalAlignment: Text.AlignRight
        		text: ''//font.pixelSize
        		Keys.onEnterPressed: focus = false
                Keys.onReturnPressed: focus = false
                onEditingFinished: if (filter.getDouble('size') !== parseFloat(text)) {
                    filter.set('size', parseFloat(text))
                    filter.set('_reload', 1)
                }
        	}
        	Label { 
        		Layout.alignment: Qt.AlignLeft
        		text: qsTr('pt') 
        	}
        	Item { width: 15 }
        	ColorPicker {
                id: colorFont
                alpha: false
                onValueChanged: {
                    filter.set('colorfont', value)
                    filter.set('_reload', 1)
                }
            }
        }
        
        Label { 
        	Layout.alignment: Qt.AlignRight
        	text: qsTr('Border') 
        }
        RowLayout {
            Layout.columnSpan: 2
            
            Item { width: 25 }
            Label { 
        		Layout.alignment: Qt.AlignRight
        		text: qsTr('Thickness ') 
        	}
        	Item { width: 1 }
        	SpinBox {
                id: contour
                Layout.minimumWidth: 40
                minimumValue: 0
                maximumValue: 10
                decimals: 0
                Keys.onEnterPressed: focus = false
                Keys.onReturnPressed: focus = false
                onValueChanged: {
                	if (hovered) forceActiveFocus()
                }
                onEditingFinished: {
                    filter.set('border', value)
                    filter.set('_reload', 1)
                }
            }
            Item { width: 15 }
        	ColorPicker {
                id: colorBorder
                alpha: false
                onValueChanged: {
                    filter.set('colorborder', value)
                    filter.set('_reload', 1)
                }
            }
            
        }
        
        Label { 
        	Layout.alignment: Qt.AlignRight
        	text: qsTr('Shadow') 
        }
        RowLayout {
            Layout.columnSpan: 2
            
            Item { width: 25 }
            Label { 
        		Layout.alignment: Qt.AlignRight
        		text: qsTr('Offset ') 
        	}
        	Item { width: 24 } // pour alignement
        	SpinBox {
                id: shadow
                Layout.minimumWidth: 40
                minimumValue: 0
                maximumValue: 10
                decimals: 0
                Keys.onEnterPressed: focus = false
                Keys.onReturnPressed: focus = false
                onValueChanged: {
                	if (hovered) forceActiveFocus()
                }
                onEditingFinished: {
                    filter.set('shadow', value)
                    filter.set('_reload', 1)
                }
            }
            Item { width: 15 }
        	ColorPicker {
                id: colorShadow
                alpha: false
                onValueChanged: {
                    filter.set('colorshadow', value)
                    filter.set('_reload', 1)
                }
            }
            Item { width: 30 }
            ToolButton {
            	implicitWidth: 26
            	implicitHeight: 26
            	iconName: 'help-about'
            	iconSource: 'qrc:///icons/oxygen/32x32/actions/help-about.png'
            	tooltip: qsTr('Affiche l\'aide pour ce filtre')
            	onClicked: helpDialog.visible = true
        		MessageDialog {
        			id: helpDialog
        			visible: false
        			modality: Qt.ApplicationModal
        			icon: StandardIcon.Information
        			text: qsTr("<u>Flip-Spin animation</u> : Elusien, Jonray & Namna<p>"
            		+ "<u>Animation</u> : Choose an animation among the 23 available animations.<p>"
            		+ "<u>Text</u> : Enter your text in the textarea, use the 'Return' key to go to the line.<p>"
                	+ "<u>Border and Shadow</u> : You can add a border to the letters and choose its color. The same to create a shadow under the text.<p>"
                	+ "<u>Background</u> : Choose its color or click on 'Transparent' to make it transparent.<p>"
                	+ "<u>Alignment</u> : Choose the paragraph alignment.<p>"
                	+ "<u>Line spacing</u> : Adjust the distance between lines, leave 100% for 1 line texts.<p>"
                	+ "<u>Lettering</u> : Allows you to increase the distance between letters.<p>"
                	+ "Other modifications of parameters managing the animations can be made with an external editor in the flipspin.js file which is located in the same folder as the .mlt file of the project at the following path :<p>" + htmlFile.url +"<p>Once your changes have been made and saved, click on the 'Reload' button to apply the update.<p>")
            		standardButtons: StandardButton.Ok
    			}
        	}
        	Label { 
            	horizontalAlignment: Text.AlignLeft
            	text: 'Help'
            }
        }
            
        Label { 
        	Layout.alignment: Qt.AlignRight
        	text: qsTr('Background') 
        }
        RowLayout {
            Layout.columnSpan: 2
            
            Item { width: 10 }
            Button {
                id: transparentButton
                Layout.preferredWidth: 103
                text: qsTr('Transparent')
            	onClicked: {
                    bgcolor.value = 'none'
                }
            }
            Item { width: 3 } // pour alignement
            Label { 
        		Layout.alignment: Qt.AlignRight
        		text: qsTr('Other ') 
        	}
        	ColorPicker {
                id: bgcolor
                alpha: false
                onValueChanged: {
                    filter.set('colorbackground', value)
                    filter.set('_reload', 1)
                }
            }
            
        }
        
        Label { 
        	Layout.alignment: Qt.AlignRight
        	text: qsTr('Text') 
        }
        RowLayout {
            Layout.columnSpan: 2
            
            Item { width: 10 }
            Label { 
        		Layout.alignment: Qt.AlignRight
        		text: qsTr('Alignment ') 
        	}
        	Item { width: 17 }
        	RadioButton {
            	id: leftRadioButton
            	text: 'Left'
            	tooltip : 'Align left'
            	exclusiveGroup: halignGroup
            	onClicked:{	
            		filter.set('textalign', 'left')
            		filter.set('_reload', 1)
            	}
        	}
        	Item { width: 10 }
        	RadioButton {
            	id: centerRadioButton
            	text: 'Center'
            	tooltip : 'Align center'
            	exclusiveGroup: halignGroup
            	onClicked:{	
            		filter.set('textalign', 'center')
            		filter.set('_reload', 1)
            	}
        	}
        	Item { width: 10 }
        	RadioButton {
            	id: rightRadioButton
            	text: 'Right'
            	tooltip : 'Align right'
            	exclusiveGroup: halignGroup
            	onClicked:{	
            		filter.set('textalign', 'right')
            		filter.set('_reload', 1)
            	}
        	}
        }
        
        Label { 
        	Layout.alignment: Qt.AlignRight
        	text: qsTr('Page setup') 
        }
        RowLayout {
            Layout.columnSpan: 2
            
            Item { width: 10 }
            Label { 
        		Layout.alignment: Qt.AlignRight
        		text: qsTr('Line spacing ') 
        	}
        	Item { width: 3 } // pour alignement
        	SpinBox {
                id: lineHeight
                Layout.minimumWidth: 70
                minimumValue: 50
                maximumValue: 500
                decimals: 0
                suffix: ' %'
                Keys.onEnterPressed: focus = false
                Keys.onReturnPressed: focus = false
                onValueChanged: {
                	if (hovered) forceActiveFocus()
                }
                onEditingFinished: {
                    filter.set('lineheight', value)
                    filter.set('_reload', 1)
                }
            }
            Item { width: 15 }
        	Label { 
        		Layout.alignment: Qt.AlignRight
        		text: qsTr('Lettering ') 
        	}
        	Item { width: 3 } // pour alignement
        	SpinBox {
                id: letterspacing
                Layout.minimumWidth: 70
                minimumValue: 0
                maximumValue: 10
                decimals: 0
                suffix: ' px'
                Keys.onEnterPressed: focus = false
                Keys.onReturnPressed: focus = false
                onValueChanged: {
                	if (hovered) forceActiveFocus()
                }
                onEditingFinished: {
                    filter.set('letterspacing', value)
                    filter.set('_reload', 1)
                }
            }
            
        }
        
        Item {
            Layout.fillHeight: true
        }
    }
}
